@@ -25,10 +25,12 @@
 # **************************************************************************
 
 EMAN2_HOME = 'EMAN2_HOME'
+EMAN2SCRATCHDIR = 'EMAN2SCRATCHDIR'
 
 # Supported versions
-V2_3 = '2.3'
 V2_31 = '2.31'
+V2_9 = '2.9'
+V2_91 = '2.91'
 
 # ------------------ Constants values -----------------------------------------
 
@@ -37,7 +39,7 @@ HIRES = 0
 MIDRES = 1
 LORES = 2
 
-# ctf invar type (version 2.3)
+# ctf invar type
 INVAR_AUTO = 0
 INVAR_BISPEC = 1
 INVAR_HARMONIC = 2
@@ -94,17 +96,18 @@ RALN_NONE = 0
 RALN_REFINE = 1
 RALN_REFINE_3D = 2
 RALN_REFINE_3D_GRID = 3
+RALN_REFINECG = 4
 
 # averagers
-AVG_ABSMAXMIN = 0
-AVG_CTF_AUTO = 1
-AVG_CTF_WEIGHT = 2
-AVG_CTF_WEIGHT_AUTOFILT = 3
-AVG_CTFW_AUTO = 4
-AVG_ITERATION = 5
-AVG_LOCALWEIGHT = 6
-AVG_MEAN = 7
-AVG_MEAN_TOMO = 8
+AVG_CTF_AUTO = 0
+AVG_CTF_WEIGHT = 1
+AVG_CTF_WEIGHT_AUTOFILT = 2
+AVG_CTFW_AUTO = 3
+AVG_ITERATIVE = 4
+AVG_LOCALWEIGHT = 5
+AVG_MEAN = 6
+AVG_MEAN_TOMO = 7
+AVG_MEDIAN = 8
 AVG_MINMAX = 9
 AVG_SIGMA = 10
 AVG_WEIGHTEDFOURIER = 11
@@ -114,16 +117,17 @@ PROC_NORMALIZE = 0
 PROC_NORMALIZE_BYMASS = 1
 PROC_NORMALIZE_CIRCLEMEAN = 2
 PROC_NORMALIZE_EDGEMEAN = 3
-PROC_NORMALIZE_LOCAL = 4
-PROC_NORMALIZE_LREDGE = 5
-PROC_NORMALIZE_MASK = 6
-PROC_NORMALIZE_MAXMIN = 7
-PROC_NORMALIZE_RAMP_NORMVAR = 8
-PROC_NORMALIZE_ROWS = 9
-PROC_NORMALIZE_TOIMAGE = 10
-PROC_NORMALIZE_UNITLEN = 11
-PROC_NORMALIZE_UNITSUM = 12
-PROC_NONE = 13
+PROC_NORMALIZE_HISTPEAK = 4
+PROC_NORMALIZE_LOCAL = 5
+PROC_NORMALIZE_LREDGE = 6
+PROC_NORMALIZE_MASK = 7
+PROC_NORMALIZE_MAXMIN = 8
+PROC_NORMALIZE_RAMP_NORMVAR = 9
+PROC_NORMALIZE_ROWS = 10
+PROC_NORMALIZE_TOIMAGE = 11
+PROC_NORMALIZE_UNITLEN = 12
+PROC_NORMALIZE_UNITSUM = 13
+PROC_NONE = 14
 
 # Reconstruction methods
 RECON_BACKPROJ = 0
@@ -138,7 +142,8 @@ RECON_NN4_CTFWS = 8
 RECON_NN4_RECT = 9
 RECON_NNSSNR = 10
 RECON_NNSSNR_CTF = 11
-RECON_WIENER_FOURIER = 12
+RECON_REAL_MEDIAN = 12
+RECON_WIENER_FOURIER = 13
 
 # modes to reconstruct with fourier method
 FOURIER_NEIGHBOR = 0
@@ -172,12 +177,14 @@ AMP_NONE = 3
 # tophat filter for e2refine_easy
 TOPHAT_NONE = 0
 TOPHAT_LOCAL = 1
-TOPHAT_GLOBAL = 2
+TOPHAT_LOCALWIENER = 2
+TOPHAT_GLOBAL = 3
 
 # e2boxer autopick modes
 AUTO_LOCAL = 0
 AUTO_REF = 1
 AUTO_CONVNET = 2
+AUTO_GAUSS = 3
 
 WIKI_URL = "[[http://blake.bcm.edu/emanwiki/EMAN2][Wiki]]"
 
