@@ -26,7 +26,6 @@
 
 import os
 import re
-from os.path import exists, basename
 from glob import glob
 
 from pwem.objects import SetOfClasses2D
@@ -37,7 +36,7 @@ from pyworkflow.protocol.params import (PointerParam, FloatParam, IntParam,
                                         LabelParam)
 from pyworkflow.utils import createLink, cleanPath
 
-from .. import Plugin, SCRATCHDIR
+from .. import Plugin
 from ..constants import *
 
 
@@ -256,7 +255,7 @@ class EmanProtRefine2DBispec(ProtClassify2D):
     # --------------------------- INSERT steps functions ----------------------
     def _insertAllSteps(self):
         self._createFilenameTemplates()
-        self._createIterTemplates(currRun=1)
+        self._createIterTemplates(currRun=self._getRun())
         self._insertFunctionStep('createLinksStep')
         args = self._prepareParams()
         self._insertFunctionStep('refineStep', args)
@@ -349,7 +348,7 @@ class EmanProtRefine2DBispec(ProtClassify2D):
                   'classiter': self.classIter.get(),
                   'threads': self.numberOfThreads.get(),
                   'mpis': self.numberOfMpi.get(),
-                  'scratch': SCRATCHDIR
+                  'scratch': Plugin.getVar(EMAN2SCRATCHDIR)
                   }
         args %= params
 
@@ -365,20 +364,20 @@ class EmanProtRefine2DBispec(ProtClassify2D):
     def _getParticlesStack(self):
         protType = self._inputProt().type.get()
         if protType == HIRES:
-            return "sets/" + basename(self._getFileName("partSetFlipLp5"))
+            return "sets/" + os.path.basename(self._getFileName("partSetFlipLp5"))
         elif protType == MIDRES:
-            return "sets/" + basename(self._getFileName("partSetFlipLp7"))
+            return "sets/" + os.path.basename(self._getFileName("partSetFlipLp7"))
         else:
-            return "sets/" + basename(self._getFileName("partSetFlipLp12"))
+            return "sets/" + os.path.basename(self._getFileName("partSetFlipLp12"))
 
     def _iterTextFile(self, iterN):
         with open(self._getFileName('results', iter=iterN)) as f:
             for line in f:
-                if '#' not in line:
+                if '#' not in line and line.strip():
                     yield [float(x) for x in line.split()]
 
     def _getRun(self):
-        return 1
+        return 0 if Plugin.isVersion('2.91') else 1
 
     def _getIterNumber(self, index):
         """ Return the list of iteration files, give the iterTemplate. """
@@ -408,7 +407,7 @@ class EmanProtRefine2DBispec(ProtClassify2D):
         if clean:
             cleanPath(data_classes)
 
-        if not exists(data_classes):
+        if not os.path.exists(data_classes):
             clsSet = SetOfClasses2D(filename=data_classes)
             clsSet.setImages(self._getInputParticles())
             self._fillClassesFromIter(clsSet, it)
@@ -436,8 +435,9 @@ class EmanProtRefine2DBispec(ProtClassify2D):
                              iterParams=params)
 
     def _execEmanProcess(self, iterN):
-        clsFn = self._getFileName("cls", run=1, iter=iterN)
-        classesFn = self._getFileName("classes", run=1, iter=iterN)
+        runN = self._getRun()
+        clsFn = self._getFileName("cls", run=runN, iter=iterN)
+        classesFn = self._getFileName("classes", run=runN, iter=iterN)
 
         proc = Plugin.createEmanProcess(args='read %s %s %s %s 2d'
                                              % (self._getParticlesStack(), clsFn, classesFn,
