@@ -36,7 +36,7 @@ from pyworkflow.protocol.params import (PointerParam, FloatParam, IntParam,
                                         EnumParam, StringParam, BooleanParam)
 from pyworkflow.utils.path import cleanPattern, makePath, createLink
 
-from .. import Plugin, SCRATCHDIR
+from .. import Plugin
 from ..convert import rowToAlignment, writeSetOfParticles
 from ..constants import *
 
@@ -136,7 +136,7 @@ Major features of this program:
                       help='The total number of refinement iterations to '
                            'perform.')
         form.addParam('tophat', EnumParam,
-                      choices=['none', 'local', 'global'],
+                      choices=['none', 'local', 'localwiener', 'global'],
                       label="Tophat filter?", default=TOPHAT_NONE,
                       display=EnumParam.DISPLAY_COMBO,
                       help='Instead of imposing a final '
@@ -206,7 +206,7 @@ Major features of this program:
                       label='Use bispectra? (experimental)',
                       help='Will use bispectra for orientation '
                            'determination (EXPERIMENTAL).')
-        form.addParam('useSetsfref', BooleanParam, default=True,
+        form.addParam('useSetsfref', BooleanParam, default=False,
                       label='Use the setsfref option in class averaging?',
                       help='This matches the filtration of the class-averages '
                            'to the projections for easier comparison. May '
@@ -264,7 +264,7 @@ Major features of this program:
         continueRun = self.continueRun.get()
         prevPartDir = continueRun._getExtraPath("particles")
         currPartDir = self._getExtraPath("particles")
-        runN = self._getRun() - 1
+        runN = self._getRun() - 1 if not Plugin.isVersion('2.91') else self._getRun()
         prevRefDir = continueRun._getExtraPath("refine_%02d" % runN)
         currRefDir = self._getExtraPath("refine_%02d" % runN)
         prevSetsDir = continueRun._getExtraPath("sets")
@@ -383,7 +383,8 @@ Major features of this program:
         return args
 
     def _prepareContinueParams(self):
-        args1 = "--startfrom=refine_%02d" % (self._getRun() - 1)
+        runN = self._getRun() - 1 if not Plugin.isVersion('2.91') else self._getRun()
+        args1 = "--startfrom=refine_%02d" % runN
         args2 = self._commonParams()
         args = args1 + args2
         return args
@@ -409,7 +410,7 @@ Major features of this program:
                   'm3dKeep': self.m3dKeep.get(),
                   'threads': self.numberOfThreads.get(),
                   'mpis': self.numberOfMpi.get(),
-                  'scratch': SCRATCHDIR
+                  'scratch': Plugin.getVar(EMAN2SCRATCHDIR)
                   }
         args %= params
 
@@ -445,7 +446,7 @@ Major features of this program:
 
     def _getRun(self):
         if not self.doContinue:
-            return 1
+            return 0 if Plugin.isVersion('2.91') else 1
         else:
             files = sorted(glob(self.continueRun.get()._getExtraPath("refine*")))
             if files:
@@ -466,7 +467,7 @@ Major features of this program:
     def _iterTextFile(self, iterN):
         with open(self._getFileName('angles', iter=iterN)) as f:
             for line in f:
-                if '#' not in line:
+                if '#' not in line and line.strip():
                     yield [float(x) for x in line.split()]
 
     def _createItemMatrix(self, item, rowList):
