@@ -1,7 +1,7 @@
 
 from .test_protocols_eman import (TestEmanBase, TestEmanAutopick,
                                   TestEmanCtfAuto, TestEmanInitialModelGroel,
-                                  TestEmanInitialModelMda, TestEmanReconstruct,
+                                  TestEmanReconstruct,
                                   TestEmanRefine2D, TestEmanRefine2DBispec,
                                   TestEmanRefineEasy, TestEmanTiltValidate,
                                   TestEmanInitialModelSGD)
